Class: Clack::Warning
- Inherits:
-
Data
- Object
- Data
- Clack::Warning
- Defined in:
- lib/clack.rb
Overview
Warning result from validation - allows user to proceed with confirmation. Validators can return a Warning to show a yellow message that doesn’t block submission if the user confirms by pressing Enter again.
Instance Attribute Summary collapse
-
#message ⇒ Object
readonly
Returns the value of attribute message.
Instance Method Summary collapse
-
#to_s ⇒ String
The warning message.
Instance Attribute Details
#message ⇒ Object (readonly)
Returns the value of attribute message
71 72 73 |
# File 'lib/clack.rb', line 71 def @message end |
Instance Method Details
#to_s ⇒ String
Returns the warning message.
73 |
# File 'lib/clack.rb', line 73 def to_s = |